@@ -24,39 +24,32 @@ const baseOpts = {
   yes: true,
 }
 
-t.test('local pkg', async t => {
+t.test('bin in local pkg', async t => {
   const pkg = {
-    name: 'pkg',
+    name: '@npmcli/local-pkg-bin-test',
     bin: {
-      a: 'index.js',
+      b: 'echo this is something else',
+      a: 'local-bin-test.js',
     },
   }
   const path = t.testdir({
     cache: {},
     npxCache: {},
-    node_modules: {
-      '.bin': {},
-      a: {
-        'index.js': `#!/usr/bin/env node
+    'local-bin-test.js': `#!/usr/bin/env node
 require('fs').writeFileSync(process.argv.slice(2)[0], 'LOCAL PKG')`,
-      },
-    },
     'package.json': JSON.stringify(pkg),
   })
   const localBin = resolve(path, 'node_modules/.bin')
   const runPath = path
+  const npxCache = resolve(path, 'npxCache')
 
-  const executable = resolve(path, 'node_modules/a')
+  const executable = resolve(path, 'local-bin-test.js')
   fs.chmodSync(executable, 0o775)
 
-  await binLinks({
-    path: resolve(path, 'node_modules/a'),
-    pkg,
-  })
-
   await libexec({
     ...baseOpts,
     args: ['a', 'resfile'],
+    npxCache,
     localBin,
     path,
     runPath,
@@ -483,7 +476,7 @@ require('fs').writeFileSync(process.argv.slice(2)[0], 'LOCAL PKG')`,
   fs.chmodSync(executable, 0o775)
 
   const mockexec = t.mock('../lib/index.js', {
-    '@npmcli/ci-detect': () => true,
+    'ci-info': { isCI: true },
     'proc-log': {
       warn (title, msg) {
         t.fail('should not warn about local file package install')
@@ -858,7 +851,7 @@ t.test('prompt, accepts', async t => {
   const npxCache = resolve(testdir, 'npxCache')
   t.test('with clearProgress function', async t => {
     const mockexec = t.mock('../lib/index.js', {
-      '@npmcli/ci-detect': () => false,
+      'ci-info': { isCI: false },
       npmlog: {
         clearProgress () {
           t.ok(true, 'should call clearProgress function')
@@ -889,7 +882,7 @@ t.test('prompt, accepts', async t => {
 
   t.test('without clearProgress function', async t => {
     const mockexec = t.mock('../lib/index.js', {
-      '@npmcli/ci-detect': () => false,
+      'ci-info': { isCI: false },
       read (opts, cb) {
         cb(null, 'y')
       },
@@ -924,7 +917,7 @@ t.test('prompt, refuses', async t => {
   const npxCache = resolve(testdir, 'npxCache')
   t.test('with clearProgress function', async t => {
     const mockexec = t.mock('../lib/index.js', {
-      '@npmcli/ci-detect': () => false,
+      'ci-info': { isCI: false },
       npmlog: {
         clearProgress () {
           t.ok(true, 'should call clearProgress function')
@@ -963,7 +956,7 @@ t.test('prompt, refuses', async t => {
 
   t.test('without clearProgress function', async t => {
     const mockexec = t.mock('../lib/index.js', {
-      '@npmcli/ci-detect': () => false,
+      'ci-info': { isCI: false },
       read (opts, cb) {
         cb(null, 'n')
       },
@@ -1070,7 +1063,7 @@ t.test('no prompt if CI', async t => {
   const cache = resolve(testdir, 'cache')
   const npxCache = resolve(testdir, 'npxCache')
   const mockexec = t.mock('../lib/index.js', {
-    '@npmcli/ci-detect': () => true,
+    'ci-info': { isCI: true },
   })
 
   await mockexec({
@@ -1099,7 +1092,7 @@ t.test('no prompt if CI, multiple packages', async t => {
   const cache = resolve(testdir, 'cache')
   const npxCache = resolve(testdir, 'npxCache')
   const mockexec = t.mock('../lib/index.js', {
-    '@npmcli/ci-detect': () => true,
+    'ci-info': { isCI: true },
     'proc-log': {
       warn (title, msg) {
         t.equal(title, 'exec', 'should warn exec title')
